Rule<T> class abstract

Constructors

Rule({String? message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
final
runOnNull bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(T? value, ValidationState state) → T?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited