RuleMetadata class

Constructors

RuleMetadata({required String name, Map<String, Object?> parameters = const <String, Object?>{}, bool runOnNull = false, String? message, bool isDynamic = false, String? dynamicReason, Map<String, Map<String, Object?>> nestedSchemas = const <String, Map<String, Object?>>{}})
const
RuleMetadata.dynamic({required String name, bool runOnNull = false, String? message, String? dynamicReason})
factory

Properties

dynamicReason String?
final
hashCode int
The hash code for this object.
no setterinherited
isDynamic bool
final
message String?
final
name String
final
nestedSchemas Map<String, Map<String, Object?>>
final
parameters Map<String, Object?>
final
runOnNull bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited
withNestedSchemas(Map<String, Map<String, Object?>> value) RuleMetadata

Operators

operator ==(Object other) bool
The equality operator.
inherited