SchemaDescriptor class

Constructors

SchemaDescriptor({required String id, required String type, required bool hasPreprocess, required List<RuleMetadata> rules, bool isReference = false, String? referenceTo})
const
SchemaDescriptor.reference({required String id, required String type, required String? referenceTo})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasPreprocess bool
final
id String
final
isReference bool
final
referenceTo String?
final
rules List<RuleMetadata>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited