ValidasiResult<T> class

Constructors

ValidasiResult({required List<ValidationError> errors, required bool isValid, T? data})
const
ValidasiResult.error(ValidationError error)
factory
ValidasiResult.success(T? data)
factory

Properties

data → T?
final
errors List<ValidationError>
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requireValue() → T?
toString() String
A string representation of this object.
inherited
toToolResponse() Map<String, Object?>
transform<R>(R f(T? value)) ValidasiResult<R>

Operators

operator ==(Object other) bool
The equality operator.
inherited