ValidationContext<T> class

Constructors

ValidationContext({required T? value})

Properties

errors List<ValidationError>
final
hashCode int
The hash code for this object.
no setterinherited
isStopped bool
getter/setter pair
requireValue → T
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T?
getter/setter pair

Methods

addError(ValidationError error) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(T? to) → void
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited