ValidationError class

Constructors

ValidationError({required String rule, required String message, Map<String, dynamic>? details, List<String>? path})
const

Properties

details Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
path List<String>?
final
rule String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toToolMap() Map<String, Object?>
withPrefix(String prefix) ValidationError

Operators

operator ==(Object other) bool
The equality operator.
inherited