MapRules class

Constructors

MapRules()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

conditionalField<T>(String field, ConditionalFieldCallback<T> callback) → ConditionalField<T>
hasFieldKeys<T>(Set<String> keys) → HasFieldKeys<T>
hasFields<T>(Map<String, ValidasiEngine<T, dynamic>> validator) → HasFields<T>