NumberRules class

Constructors

NumberRules()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

finite({String? message}) → Finite
lessThan<T extends num>(T value, {String? message}) → LessThan<T>
lessThanEqual<T extends num>(T value, {String? message}) → LessThanEqual<T>
moreThan<T extends num>(T value, {String? message}) → MoreThan<T>
moreThanEqual<T extends num>(T value, {String? message}) → MoreThanEqual<T>