Transform<T> class

Inheritance

Constructors

Transform(T? transform(T?), {String? message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
finalinherited
metadata RuleMetadata
no setteroverride
metadataChildren Map<String, Object?>
no setterinherited
runOnNull bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform → T? Function(T?)
final

Methods

apply(ValidationContext<T> context) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited