ValidasiTransformation<TInput, TOutput> class

Constructors

ValidasiTransformation(TransformFn<TInput, TOutput> transform, {String? message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform TransformFn<TInput, TOutput>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tryTransform(TInput input) ValidasiTransformationResult<TInput, TOutput>

Operators

operator ==(Object other) bool
The equality operator.
inherited