ValidasiTransformationResult<I, O> class

Constructors

ValidasiTransformationResult({required bool isValid, O? data, Object? error, String? message})
const
ValidasiTransformationResult.error(Object error, {String? message})
factory
ValidasiTransformationResult.success(O data, {String? message})
factory

Properties

data → O?
final
error Object?
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited