Rule<T> class abstract

Implementers

Constructors

Rule({String? message})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
final
metadata RuleMetadata
no setter
metadataChildren Map<String, Object?>
no setter
runOnNull bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(ValidationContext<T> context) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited