ValidasiEngine<T, TInput> class
Constructors
-
ValidasiEngine({List<
Rule< ? rules, ValidasiTransformation<T> >dynamic, T> ? preprocess}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
preprocess
→ ValidasiTransformation<
dynamic, T> ? -
final
-
rules
→ List<
Rule< ?T> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
introspect(
) → SchemaDescriptor -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
TInput? value) → ValidasiResult< T> -
withPreprocess<
TNextInput> (ValidasiTransformation< TNextInput, T> preprocess) → ValidasiEngine<T, TNextInput>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited