Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
anyOf<T>(List<List<Rule<T>>> ruleSets, {String? message})
→ AnyOf<T>
-
-
equals<T>(T expected, {bool equals(T a, T b)?, String? message})
→ Equals<T>
-
-
having<T>(List<T> validValues, {String? message})
→ Having<T>
-
-
inline<T>(bool validator(T? value), {String? message, String name = 'inline_rule'})
→ InlineRule<T>
-
-
notEquals<T>(T unexpected, {bool equals(T a, T b)?, String? message})
→ NotEquals<T>
-
-
nullable<T>()
→ Nullable<T>
-
-
required<T>({String? message})
→ Required<T>
-
-
transform<T>(T? transformer(T? value), {String? message})
→ Transform<T>
-
Constants
-
iterable
→ const _IterableRules
-
-
map
→ const _MapRules
-
-
number
→ const _NumberRules
-
-
string
→ const _StringRules
-